@@ -41,7 +41,8 @@ MakeResultFPCA <- function(optns, smcObj, mu, scsObj, eigObj,
                 smoothedCov = ConvertSupport(workGrid, obsGrid, Cov=scsObj$smoothCov), 
                 FVE = eigObj$cumFVE[eigObj$kChoosen], 
                 cumFVE =  eigObj$cumFVE, 
-                fittedCov = ConvertSupport(workGrid, obsGrid, Cov=eigObj$fittedCovUser), 
+                fittedCov = ConvertSupport(workGrid, obsGrid, Cov=eigObj$fittedCovUser),
+                fittedCorr = ConvertSupport(workGrid, obsGrid, Cov=eigObj$fittedCorrUser),
                 optns = optns, 
                 bwMu = smcObj$bw_mu, 
                 bwCov = scsObj$bwCov)
@@ -58,6 +59,7 @@ MakeResultFPCA <- function(optns, smcObj, mu, scsObj, eigObj,
               FVE = eigObj$cumFVE[eigObj$kChoosen], 
               cumFVE =  eigObj$cumFVE, 
               fittedCov = eigObj$fittedCovUser, 
+              fittedCorr = eigObj$fittedCorrUser, 
               optns = optns, 
               bwMu = smcObj$bw_mu, 
               bwCov = scsObj$bwCov)
